@@ -1,5 +1,5 @@
 package String::Lookup::AsyncDBI;
-$VERSION= 0.14;
+$VERSION= 0.15;
 
 # what runtime features we need
 use 5.014;
@@ -146,7 +146,7 @@ String::Lookup::AsyncDBI - flush String::Lookup to flat files
 
 =head1 VERSION
 
-This documentation describes version 0.14.
+This documentation describes version 0.15.
 
 =head1 DESCRIPTION
 
@@ -184,10 +184,12 @@ environment variable.
 
  Elizabeth Mattijsen
 
+Maintained by LNATION <email@lnation.org>
+
 =head1 COPYRIGHT
 
-Copyright (c) 2012 Elizabeth Mattijsen <liz@dijkmat.nl>.  All rights reserved.
-This program is free software; you can redistribute it and/or modify it under
+Copyright (c) 2012 Elizabeth Mattijsen <liz@dijkmat.nl>. 2025 LNATION <email@lnation.org>
+All rights reserved. This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
 =cut
